@@ -1,67 +1,69 @@
 var languageNames = {
 "en-US": "Engelsk (USA)",
+"sq": "Albansk",
 "am": "Amharisk",
 "ar": "Arabisk",
 "ast": "Asturisk",
-"bg": "Bulgarsk",
 "bn": "Bengali",
 "bn-IN": "Bengali (Indien)",
-"bo": "Tibetansk",
 "bs": "Bosnisk",
+"bg": "Bulgarsk",
 "ca": "Catalansk",
-"ca-valencia": "Valenciansk catalansk",
+"ca-valencia": "Catalan (Valencia)",
+"zh-CN": "Kinesisk (simplificeret)",
+"zh-TW": "Kinesisk (traditionelt)",
+"hr": "Kroatisk",
 "cs": "Tjekkisk",
 "da": "Dansk",
-"de": "Tysk",
+"nl": "Hollandsk",
 "dz": "Dzongkha",
-"el": "Græsk",
 "en-GB": "Engelsk (UK)",
 "en-ZA": "Engelsk (SA)",
 "eo": "Esperanto",
-"es": "Spansk",
 "et": "Estisk",
 "eu": "Baskisk",
 "fi": "Finsk",
 "fr": "Fransk",
 "gl": "Galicisk",
+"ka": "Georgisk",
+"de": "Tysk",
+"el": "Græsk",
 "gu": "Gujarati",
 "he": "Hebræisk",
 "hi": "Hindi",
-"hr": "Kroatisk",
 "hu": "Ungarsk",
 "id": "Indonesisk",
 "is": "Islandsk",
 "it": "Italiensk",
 "ja": "Japansk",
-"ka": "Georgisk",
 "km": "Khmer",
 "ko": "Koreansk",
 "lo": "Laotisk",
-"lt": "Litauisk",
 "lv": "Lettisk",
+"lt": "Litauisk",
 "mk": "Makedonsk",
-"nb": "Norsk bokmål",
 "ne": "Nepalesisk",
-"nl": "Hollandsk",
 "nn": "Norsk nynorsk",
+"nb": "Norsk bokmål",
 "om": "Oromo",
 "pl": "Polsk",
 "pt": "Portugisisk",
-"pt-BR": "Brasiliansk portugisisk",
+"pt-BR": "Portuguese (Brazil)",
 "ro": "Rumænsk",
 "ru": "Russisk",
-"si": "Singalesisk",
 "sid": "Sidama",
+"si": "Singalesisk",
 "sk": "Slovakisk",
 "sl": "Slovensk",
-"sq": "Albansk",
+"dsb": "Sorbian (Lower)",
+"hsb": "Sorbian (Upper)",
+"es": "Spansk",
 "sv": "Svensk",
-"ta": "Tamilsk",
 "tg": "tadsjikisk",
+"ta": "Tamilsk",
+"bo": "Tibetansk",
 "tr": "Tyrkisk",
 "ug": "Uyghur",
 "uk": "Ukrainsk",
 "vi": "Vietnamesisk",
-"zh-CN": "Kinesisk (simplificeret)",
-"zh-TW": "Kinesisk (traditionelt)",
 };
